@@ -1,4 +1,4 @@
-// Copyright (C) 2016 Yixuan Qiu <yixuan.qiu@cos.name>
+// Copyright (C) 2016-2026 Yixuan Qiu <yixuan.qiu@cos.name>
 //
 // This Source Code Form is subject to the terms of the Mozilla
 // Public License v. 2.0. If a copy of the MPL was not distributed
@@ -9,6 +9,9 @@
 
 #include <RcppEigen.h>
 
+// Functor definition
+#include "Func.h"
+
 // Integration
 #include "integration/GaussKronrodNodesWeights.h"
 #include "integration/Integrator.h"
